@@ -47,7 +47,7 @@ import (
 )
 
 const (
-	version    = "v1.30.1"
+	version    = "v1.31.0"
 	copyright  = "GoAWK " + version + " - Copyright (c) 2022 Ben Hoyt"
 	shortUsage = "usage: goawk [-F fs] [-v var=value] [-f progfile | 'prog'] [file ...]"
 	longUsage  = `Standard AWK arguments:
@@ -357,11 +357,10 @@ argsLoop:
 		},
 	}
 	for _, v := range vars {
-		equals := strings.IndexByte(v, '=')
-		if equals < 0 {
+		name, value, ok := strings.Cut(v, "=")
+		if !ok {
 			errorExitf("-v flag must be in format name=value")
 		}
-		name, value := v[:equals], v[equals+1:]
 		// Oddly, -v must interpret escapes (issue #129)
 		unescaped, err := lexer.Unescape(value)
 		if err == nil {
@@ -450,7 +449,7 @@ func showSourceLine(src []byte, pos lexer.Position) {
 	srcLine := string(lines[pos.Line-1])
 	numTabs := strings.Count(srcLine[:pos.Column-1], "\t")
 	runeColumn := utf8.RuneCountInString(srcLine[:pos.Column-1])
-	fmt.Fprintln(os.Stderr, strings.Replace(srcLine, "\t", "    ", -1))
+	fmt.Fprintln(os.Stderr, strings.ReplaceAll(srcLine, "\t", "    "))
 	fmt.Fprintln(os.Stderr, strings.Repeat(" ", runeColumn)+strings.Repeat("   ", numTabs)+"^")
 }
 
@@ -462,7 +461,7 @@ func errorExit(err error) {
 	errorExitf("%s", err)
 }
 
-func errorExitf(format string, args ...interface{}) {
+func errorExitf(format string, args ...any) {
 	fmt.Fprintf(os.Stderr, format+"\n", args...)
 	os.Exit(1)
 }
