@@ -465,7 +465,7 @@ func IsLValue(expr Expr) bool {
 
 // formatRegex formats the regex string r.
 func formatRegex(r string) string {
-	escaped := strings.Replace(r, "/", `\/`, -1)
+	escaped := strings.ReplaceAll(r, "/", `\/`)
 	return "/" + escaped + "/"
 }
 
@@ -788,7 +788,7 @@ type PositionError struct {
 }
 
 // PosErrorf like fmt.Errorf, but with an explicit position.
-func PosErrorf(pos Position, format string, args ...interface{}) error {
+func PosErrorf(pos Position, format string, args ...any) error {
 	message := fmt.Sprintf(format, args...)
 	return &PositionError{pos, message}
 }
