@@ -11,13 +11,13 @@ import (
 	"os"
 	"os/exec"
 	"regexp"
-	"runtime"
 	"strconv"
 	"strings"
+	"time"
 	"unicode/utf8"
 
 	"github.com/benhoyt/goawk/internal/resolver"
-	. "github.com/benhoyt/goawk/lexer"
+	"github.com/benhoyt/goawk/lexer"
 )
 
 // Print a line of output followed by a newline
@@ -98,7 +98,7 @@ func (p *interp) writeCSV(output io.Writer, fields []string) error {
 
 // Determine the output stream for given redirect token and
 // destination (file or pipe name)
-func (p *interp) getOutputStream(redirect Token, destValue value) (io.Writer, error) {
+func (p *interp) getOutputStream(redirect lexer.Token, destValue value) (io.Writer, error) {
 	name := p.toString(destValue)
 	if _, ok := p.inputStreams[name]; ok {
 		return nil, newError("can't write to reader stream")
@@ -108,7 +108,7 @@ func (p *interp) getOutputStream(redirect Token, destValue value) (io.Writer, er
 	}
 
 	switch redirect {
-	case GREATER, APPEND:
+	case lexer.GREATER, lexer.APPEND:
 		// Write or append to file
 		if name == "-" {
 			// filename of "-" means write to stdout, eg: print "x" >"-"
@@ -117,13 +117,20 @@ func (p *interp) getOutputStream(redirect Token, destValue value) (io.Writer, er
 		if p.noFileWrites {
 			return nil, newError("can't write to file due to NoFileWrites")
 		}
-		if runtime.GOOS == "windows" && name == "/dev/stderr" {
-			// Special case /dev/stderr on Windows to allow portably printing to stderr.
-			return p.errorOutput, nil
-		}
+
 		p.flushOutputAndError() // ensure synchronization
+
+		// No need to open /dev/stdout or /dev/stderr, just use existing streams.
+		// This also makes writing to these stream names portable on Windows.
+		switch name {
+		case "/dev/stderr":
+			return p.errorOutput, nil
+		case "/dev/stdout":
+			return p.output, nil
+		}
+
 		flags := os.O_CREATE | os.O_WRONLY
-		if redirect == GREATER {
+		if redirect == lexer.GREATER {
 			flags |= os.O_TRUNC
 		} else {
 			flags |= os.O_APPEND
@@ -136,7 +143,7 @@ func (p *interp) getOutputStream(redirect Token, destValue value) (io.Writer, er
 		p.outputStreams[name] = out
 		return out, nil
 
-	case PIPE:
+	case lexer.PIPE:
 		// Pipe to command
 		if p.noExec {
 			return nil, newError("can't write to pipe due to NoExec")
@@ -164,11 +171,16 @@ func (p *interp) execShell(code string) *exec.Cmd {
 	executable := p.shellCommand[0]
 	args := p.shellCommand[1:]
 	args = append(args, code)
+
+	var cmd *exec.Cmd
 	if p.checkCtx {
-		return exec.CommandContext(p.ctx, executable, args...)
+		cmd = exec.CommandContext(p.ctx, executable, args...)
 	} else {
-		return exec.Command(executable, args...)
+		cmd = exec.Command(executable, args...)
 	}
+	// Ensure stdout/stderr pipes being held open don't keep process running.
+	cmd.WaitDelay = 250 * time.Millisecond
+	return cmd
 }
 
 // Get input Scanner to use for "getline" based on file name
@@ -620,12 +632,18 @@ func (p *interp) setLine(line string, isTrueStr bool) {
 	p.lineIsTrueStr = isTrueStr
 	p.haveFields = false
 	p.reparseCSV = true
+
+	// POSIX says that fields should be evaluated as if they were split using
+	// the value of FS at the time that record's value was read. Because we
+	// split fields lazily, we need to save FS here.
+	p.savedFieldSep = p.fieldSep
+	p.savedFieldSepRegex = p.fieldSepRegex
 }
 
 // Splits on FS as a regex, appending each field to fields and returning the
 // new slice (for efficiency).
 func (p *interp) splitOnFieldSepRegex(fields []string, line string) []string {
-	indices := p.fieldSepRegex.FindAllStringIndex(line, -1)
+	indices := p.savedFieldSepRegex.FindAllStringIndex(line, -1)
 	prevIndex := 0
 	for _, match := range indices {
 		start, end := match[0], match[1]
@@ -665,14 +683,14 @@ func (p *interp) ensureFields() {
 				p.fields = nil
 			}
 		}
-	case p.fieldSep == " ":
+	case p.savedFieldSep == " ":
 		// FS space (default) means split fields on any whitespace
 		p.fields = strings.Fields(p.line)
 	case p.line == "":
 		p.fields = nil
-	case utf8.RuneCountInString(p.fieldSep) <= 1:
+	case utf8.RuneCountInString(p.savedFieldSep) <= 1:
 		// 1-char FS is handled as plain split (not regex)
-		p.fields = strings.Split(p.line, p.fieldSep)
+		p.fields = strings.Split(p.line, p.savedFieldSep)
 	default:
 		// Split on FS as a regex
 		p.fields = p.splitOnFieldSepRegex(p.fields[:0], p.line)
@@ -681,7 +699,7 @@ func (p *interp) ensureFields() {
 	// Special case for when RS=="" and FS is single character,
 	// split on newline in addition to FS. See more here:
 	// https://www.gnu.org/software/gawk/manual/html_node/Multiple-Line.html
-	if p.inputMode == DefaultMode && p.recordSep == "" && utf8.RuneCountInString(p.fieldSep) == 1 {
+	if p.inputMode == DefaultMode && p.recordSep == "" && utf8.RuneCountInString(p.savedFieldSep) == 1 {
 		fields := make([]string, 0, len(p.fields))
 		for _, field := range p.fields {
 			lines := strings.Split(field, "\n")
@@ -737,7 +755,7 @@ func (p *interp) nextLine() (string, error) {
 					// Yep, set variable to value and keep going
 					name, val := matches[1], matches[2]
 					// Oddly, var=value args must interpret escapes (issue #129)
-					unescaped, err := Unescape(val)
+					unescaped, err := lexer.Unescape(val)
 					if err == nil {
 						val = unescaped
 					}
@@ -798,8 +816,8 @@ func writeOutput(w io.Writer, s string, crlfNewline bool) error {
 		// First normalize to \n, then convert all newlines to \r\n
 		// (on Windows). NOTE: creating two new strings is almost
 		// certainly slow; would be better to create a custom Writer.
-		s = strings.Replace(s, "\r\n", "\n", -1)
-		s = strings.Replace(s, "\n", "\r\n", -1)
+		s = strings.ReplaceAll(s, "\r\n", "\n")
+		s = strings.ReplaceAll(s, "\n", "\r\n")
 	}
 	_, err := io.WriteString(w, s)
 	return err
@@ -880,7 +898,7 @@ func (p *interp) flushOutputAndError() {
 }
 
 // Print a message to the error output stream, flushing as necessary.
-func (p *interp) printErrorf(format string, args ...interface{}) {
+func (p *interp) printErrorf(format string, args ...any) {
 	if flusher, ok := p.output.(flusher); ok {
 		_ = flusher.Flush() // ensure synchronization
 	}
