@@ -64,13 +64,13 @@ func (p *Interpreter) Execute(config *Config) (int, error) {
 // Array returns a map representing the items in the named AWK array. AWK
 // numbers are included as type float64, strings (including "numeric strings")
 // are included as type string. If the named array does not exist, return nil.
-func (p *Interpreter) Array(name string) map[string]interface{} {
+func (p *Interpreter) Array(name string) map[string]any {
 	index, exists := p.interp.arrayIndexes[name]
 	if !exists {
 		return nil
 	}
 	array := p.interp.array(resolver.Global, index)
-	result := make(map[string]interface{}, len(array))
+	result := make(map[string]any, len(array))
 	for k, v := range array {
 		switch v.typ {
 		case typeNum:
@@ -132,6 +132,8 @@ func (p *interp) resetVars() {
 	p.outputFormat = "%.6g"
 	p.fieldSep = " "
 	p.fieldSepRegex = nil
+	p.savedFieldSep = " "
+	p.savedFieldSepRegex = nil
 	p.recordSep = "\n"
 	p.recordSepRegex = nil
 	p.recordTerminator = ""
@@ -161,8 +163,8 @@ func (p *Interpreter) ResetRand() {
 // set an execution timeout or cancel the execution. For efficiency, the
 // context is only tested every 1000 virtual machine instructions.
 //
-// Context handling is not preemptive: currently long-running operations like
-// system() won't be interrupted.
+// Context handling is not preemptive: some long-running operations may not
+// be interrupted when the context is cancelled.
 func (p *Interpreter) ExecuteContext(ctx context.Context, config *Config) (int, error) {
 	p.interp.resetCore()
 	p.interp.checkCtx = ctx != context.Background() && ctx != context.TODO()
