@@ -7,6 +7,7 @@ import (
 	"context"
 	"errors"
 	"math"
+	"runtime"
 	"strings"
 	"testing"
 	"time"
@@ -167,13 +168,25 @@ func TestExecuteContextCancel(t *testing.T) {
 }
 
 func TestExecuteContextSystemTimeout(t *testing.T) {
-	t.Skip("TODO: skipping for now due to #122")
-	interpreter := newInterp(t, `BEGIN { print system("sleep 4") }`)
+	start := time.Now()
+	interpreter := newInterp(t, `BEGIN { print system("sleep 1") }`)
 	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Millisecond)
 	defer cancel()
+
 	_, err := interpreter.ExecuteContext(ctx, nil)
-	if !errors.Is(err, context.DeadlineExceeded) {
-		t.Fatalf("expected DeadlineExceeded error, got: %v", err)
+	switch runtime.GOOS {
+	case "windows", "darwin":
+		// For some reason on Windows and macOS the returned error is nil, rather
+		// than DeadlineExceeded. Don't check it on those platforms.
+	default:
+		if !errors.Is(err, context.DeadlineExceeded) {
+			t.Fatalf("expected DeadlineExceeded error, got: %v", err)
+		}
+	}
+
+	elapsed := time.Since(start)
+	if elapsed > 500*time.Millisecond {
+		t.Fatalf("should have taken ~5ms, took %v", elapsed)
 	}
 }
 
